(defcustom latex-auto-coding-alist
  '(("ansinew" . windows-1252)
    ("applemac" . mac-roman)
    ("ascii" . us-ascii)
    ;; ("cp1250" . undecided) ; MS Windows encoding, codepage 1250
    ("cp1252" . windows-1252)
    ;; ("cp437de" . undecided) ; IBM codepage 437
    ;; ("cp437" . undecided) ; IBM codepage 437
    ;; ("cp850" . undecided) ; IBM codepage 850
    ;; ("cp852" . undecided) ; IBM codepage 852
    ;; ("cp865" . undecided) ; IBM codepage 865
    ;; ("decmulti" . undecided) ; The DECMultinational charaterset used by the OpenVMS system
    ("latin1" . iso-8859-1) 
    ("latin2" . iso-8859-2)
    ("latin3" . iso-8859-3)
    ("latin4" . iso-8859-4)
    ("latin5" . iso-8859-5)
    ("latin9" . iso-8859-15)
    ;; ("next" . undecided) ; The Next encoding
    ("utf8" . utf-8))
  "Mapping from LaTeX's inputenc.sty encoding names to Emacs' coding system names.
Used by the function `latex-auto-coding-function'."
  :group 'mule
  :type '(alist :key-type (string :tag "LaTeX input encoding")
		:value-type (coding-system :tag "Coding system"))
)

(defun latex-auto-coding-function (size)
  "Determine the encoding of a LaTeX buffer if it uses inputenc.sty.

This function is intended to be added to `auto-coding-functions'.

The mapping from LaTeX's inputenc.sty encoding names to Emacs'
coding system names is determined from `latex-auto-coding-alist'."
  (setq size (+ (point) size))
  (when (re-search-forward "\\usepackage\\[\\(.*\\)\\]{inputenc}" size t)
    (let* ((match (match-string 1)))
      (let* ((inputenc-match (cdr (assoc match latex-auto-coding-alist))))
	(let* ((sym (intern match)))
	  (if inputenc-match (setq sym inputenc-match) nil)
	  (if (coding-system-p sym)
	      sym
	    nil)
	  )))))
